@@ -38,12 +38,12 @@ public Q_SLOTS:
     void newLocalWallet();
     void newNetworkWallet();
     void updateWalletLists();
-    QString newWallet();
     void deleteEntry();
     void customContextMenuRequested(const QPoint &pos);
 
 private:
-    WalletConfigWidget *_wcw;
+    QString newWallet();
+    WalletConfigWidget *const _wcw;
     KSharedConfig::Ptr _cfg;
 };
 
