@@ -26,10 +26,7 @@ KWalletManagerWidget::KWalletManagerWidget(QWidget *parent, Qt::WindowFlags /*fl
     connect(this, &KWalletManagerWidget::currentPageChanged, this, &KWalletManagerWidget::onCurrentPageChanged);
 }
 
-KWalletManagerWidget::~KWalletManagerWidget()
-{
-
-}
+KWalletManagerWidget::~KWalletManagerWidget() = default;
 
 void KWalletManagerWidget::onCurrentPageChanged(KPageWidgetItem */*current*/, KPageWidgetItem */*before*/)
 {
@@ -110,7 +107,7 @@ QString KWalletManagerWidget::activeWalletName() const
     if (page) {
         return page->walletName();
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -149,7 +146,7 @@ void KWalletManagerWidget::dropEvent(QDropEvent */*e*/)
 //         // Not dropped over an item thus it is a wallet
 //         const QString dest = KGlobal::dirs()->saveLocation("kwallet") + u.fileName();
 //         if (QFile::exists(dest)) {
-//             KMessageBox::sorry(viewport(), i18n("That wallet file already exists.  You cannot overwrite wallets."));
+//             KMessageBox::error(viewport(), i18n("That wallet file already exists.  You cannot overwrite wallets."));
 //             e->ignore();
 //             return;
 //         }
